@@ -112,15 +112,18 @@ setOnSlave = function(x, resources.path=as.character(NA)) {
   options(BatchJobs.resources.path=resources.path)
 }
 
+# FIXME BBmisc
 getOperatingSystem = function() {
-  Sys.info()["sysname"]
+  .Platform$OS.type
 }
 
-
+# FIXME BBmisc
 now = function() {
   as.integer(Sys.time())
 }
 
+#FIXME: why dont we depent on stringr for this?
+
 # Extract a FIRST match for a pattern from a vector of strings.
 # @param x [\code{character}]\cr
 #   Vector of strings.
@@ -142,6 +145,7 @@ strextract = function(x, pattern) {
   }, x, starts, stops, USE.NAMES=FALSE)
 }
 
+#FIXME: why dont we depent on stringr for this?
 trim = function(x, ltrim=TRUE, rtrim=TRUE) {
   if (ltrim)
     x = sub("^[[:space:]]+", "", x)
@@ -150,20 +154,13 @@ trim = function(x, ltrim=TRUE, rtrim=TRUE) {
   return(x)
 }
 
-### FIXME this is going to BBmisc!
-names2 = function(x, missing.val="") {
-  n = names(x)
-  if (is.null(n))
-    return(rep.int(missing.val, length(x)))
-  replace(n, is.na(n) | n == "", missing.val)
-}
-
+# FIXME BBmisc
 list2df = function(li, force.names=FALSE, strings.as.factors = default.stringsAsFactors()) {
   if (length(li) == 0L)
     return(as.data.frame(matrix(nrow = 0L, ncol = 0L)))
 
   if (force.names) {
-    li = lapply(li, function(x) setNames(x, make.names(names2(x), unique=TRUE)))
+    li = lapply(li, function(x) setNames(x, make.names(names2(x, ""), unique=TRUE)))
   }
 
   cols = unique(unlist(lapply(li, names)))
@@ -179,6 +176,7 @@ list2df = function(li, force.names=FALSE, strings.as.factors = default.stringsAs
   as.data.frame(res, stringsAsFactors = strings.as.factors)
 }
 
+# FIXME BBmisc
 shortenString = function(x, len, str.short="...") {
   if (is.na(x))
     return(NA_character_)
@@ -186,3 +184,29 @@ shortenString = function(x, len, str.short="...") {
     return(paste(substr(x, 1L, len - nchar(str.short)), str.short, sep=""))
   return(x)
 }
+
+getArgNames = function(args, argnames) {
+  if (!length(args))
+    return(NULL)
+  if (!missing(argnames)) {
+    if (!is.null(argnames))
+      checkArg(argnames, "character", len=length(args))
+    return(argnames)
+  }
+  if (is.null(names(args[[1L]])) && is.character(args[[1L]]))
+      return(args[[1L]])
+  return(names(args[[1L]]))
+}
+
+convertUseNames = function(use.names) {
+  if (is.character(use.names) && length(use.names) == 1L && use.names %in% c("none", "ids", "names"))
+    return(use.names)
+  
+  # FIXME re-add this for the next release
+  # warning("Logical values for 'use.names' is deprecated and will be removed in a future version. Use 'none', 'ids' or 'names' instead.") 
+  checkArg(use.names, "logical", len=1L, na.ok=FALSE)
+  c("none", "ids")[use.names+1L]
+}
+
+# FIXME remove this after CRAN upload
+names2 = BBmisc::names2
