@@ -59,7 +59,8 @@ testJob = function(reg, id, resources=list()) {
 
   # write r script
   resources.timestamp = saveResources(reg, resources)
-  writeRscripts(reg, id, resources.timestamp, disable.mail=TRUE, delays=0, interactive.test=FALSE)
+  writeRscripts(reg, getClusterFunctions(conf), id, chunks.as.arrayjobs=FALSE, resources.timestamp=resources.timestamp,
+                disable.mail=TRUE, delays=0, interactive.test=FALSE)
 
   # execute
   rhome = Sys.getenv("R_HOME")
