@@ -21,8 +21,8 @@
 #'   Default is \code{604800} (one week).
 #' @param stop.on.error [\code{logical(1)}]\cr
 #'   Immediatly return if a job terminates with an error? Default is \code{FALSE}.
-#' @return Returns \code{TRUE} if all jobs terminated and \code{FALSE} if either
-#'   \code{stop.on.error} is \code{TRUE} and an error occured or the timeout is reached.
+#' @return Returns \code{TRUE} if all jobs terminated successfully and \code{FALSE} if either
+#'   an error occured or the timeout is reached.
 #' @export
 waitForJobs = function(reg, ids, sleep = 10, timeout = 604800, stop.on.error = FALSE) {
   checkRegistry(reg)
@@ -42,36 +42,38 @@ waitForJobs = function(reg, ids, sleep = 10, timeout = 604800, stop.on.error = F
   checkArg(stop.on.error, "logical", len=1L, na.ok=FALSE)
 
   n = length(ids)
-  if (n > 0L) {
-    timeout = now() + timeout
-    bar = makeProgressBar(min=0L, max=n, label="Waiting                  ")
+  if (n == 0L)
+    return(TRUE)
 
-    repeat {
-      # FIXME overhead in query
-      on.sys = length(dbFindOnSystem(reg, ids, batch.ids = batch.ids))
-      stats = dbGetStats(reg, ids, running=TRUE, expired=FALSE, times=FALSE, batch.ids = batch.ids)
-      bar$set(n - on.sys, msg = sprintf("Waiting [S:%i R:%i D:%i E:%i]", on.sys, stats$running, stats$done, stats$error))
-      on.exit(bar$kill())
+  timeout = now() + timeout
+  bar = makeProgressBar(min=0L, max=n, label="Waiting                  ")
+  on.exit(bar$kill())
+  on.sys = ids
 
-      if (stop.on.error && stats$error > 0L) {
-        err = dbGetErrorMsgs(reg, ids, filter=TRUE, limit=1L)
-        messagef("Job $i terminated with an error: %s", err$job_id, err$error)
-        return(FALSE)
-      }
+  repeat {
+    on.sys = dbFindOnSystem(reg, on.sys, batch.ids = batch.ids)
+    n.on.sys = length(on.sys)
+    stats = dbGetStats(reg, ids, running=TRUE, expired=FALSE, times=FALSE, batch.ids = batch.ids)
+    bar$set(n - n.on.sys, msg = sprintf("Waiting [S:%i R:%i D:%i E:%i]", n.on.sys, stats$running, stats$done, stats$error))
 
-      if (on.sys == 0L || is.finite(timeout) && now() > timeout)
-        break
-
-      Sys.sleep(sleep)
-      suppressMessages(syncRegistry(reg))
-      batch.ids = getBatchIds(reg, "Cannot find jobs on system")
-    }
-
-    if (on.sys > 0L) {
-      messagef("Timeout reached. %i jobs still on system.", on.sys)
+    if (stop.on.error && stats$error > 0L) {
+      err = dbGetErrorMsgs(reg, ids, filter=TRUE, limit=1L)
+      messagef("Job %i terminated with an error: %s", err$job_id, err$error)
       return(FALSE)
     }
+
+    if (n.on.sys == 0L || (is.finite(timeout) && now() > timeout))
+      break
+
+    Sys.sleep(sleep)
+    suppressMessages(syncRegistry(reg))
+    batch.ids = getBatchIds(reg, "Cannot find jobs on system")
   }
-  message("All jobs terminated.")
-  return(TRUE)
+
+  if (n.on.sys > 0L) {
+    messagef("Timeout reached. %i jobs still on system.", n.on.sys)
+    return(FALSE)
+  }
+
+  return(!dbAnyErrors(reg, ids))
 }
