@@ -2,6 +2,7 @@
 #' @import utils
 #' @import DBI
 #' @import RSQLite
+#' @import fail
 #' @importFrom digest digest
 #' @importFrom brew brew
 #' @importFrom sendmailR sendmail
@@ -11,18 +12,19 @@
 
 .onAttach = function(libname, pkgname) {
   if (!isOnSlave()) {
-    packageStartupMessage(collapse(capture.output(showConf()), "\n"))
-  }
-}
-
-.onLoad = function(libname, pkgname) {
-  if (!isOnSlave()) {
-    assignConfDefaults()
     if (missing(libname) || missing(pkgname)) {
       # this can happen with testthat while loading from skel/
       readConfs(find.package(package = "BatchJobs"))
     } else {
       readConfs(file.path(libname, pkgname))
     }
+    packageStartupMessage(printableConf(getConfig()))
+  }
+}
+
+.onLoad = function(libname, pkgname) {
+  options(BatchJobs.check.posix = getOption("BatchJobs.check.posix", default = TRUE))
+  if (!isOnSlave()) {
+    assignConfDefaults()
   }
 }
