@@ -48,6 +48,6 @@ test_that("submitJobs works with chunking", {
   expect_equal(findDone(reg), 1:4)
   submitJobs(reg, ids=ch)
   expect_equal(findDone(reg), 1:5)
-  expect_equal(loadResults(reg, simplify=TRUE, use.names=FALSE), 1:5)
+  expect_equal(loadResults(reg, simplify=TRUE, use.names="none"), 1:5)
 })
 
